@@ -17,8 +17,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef DEFS_H
-#define DEFS_H
+#ifndef GDB_DEFS_H
+#define GDB_DEFS_H
 
 #ifdef GDBSERVER
 #  error gdbserver should not include gdb/defs.h
@@ -443,4 +443,4 @@ struct arch_addr_space
 
 #include "utils.h"
 
-#endif /* #ifndef DEFS_H */
+#endif /* GDB_DEFS_H */
